@@ -35,6 +35,7 @@ class KakiRequestHandler
 		@response_header = nil
 
 		@request_command = nil
+		@request_max_number = nil
 		@request_content_source = nil
 		@request_edit_key = nil
 		@request_language_list = nil
@@ -44,6 +45,7 @@ class KakiRequestHandler
 
 		@script_path = nil
 		@server_uri = nil
+		@remote_address = nil
 		@site_property = nil
 
 		@theme_base_url = nil
@@ -193,6 +195,14 @@ protected
 		@site_property
 	end
 
+	def script_path
+		unless @script_path then
+			@script_path = self.request_variables['SCRIPT_NAME'].to_s
+			@script_path = '/' if @script_path.length <= 0
+		end
+		@script_path
+	end
+
 	def server_uri
 		unless @server_uri then
 			if request_variables['HTTPS'] then
@@ -212,14 +222,23 @@ protected
 		@server_uri
 	end
 
-	def script_path
-		unless @script_path then
-			@script_path = self.request_variables['SCRIPT_NAME'].to_s
-			@script_path = '/' if @script_path.length <= 0
+	def remote_address
+		unless @remote_address then
+			@remote_address = request_variables['REMOTE_ADDR']
 		end
-		@script_path
+		@remote_address
 	end
 
+	def ignore_site_access?()
+		result = false;
+		ignore_list = site_property['ignore_sites'].split(",")
+		ignore_list.each(){ |ignore_ip|
+			if Regexp.new(ignore_ip) =~ self.remote_address then
+				result = true;
+			end
+		}
+		result
+	end
 
 	def data
 		unless @data then
@@ -269,7 +288,9 @@ protected
 				data[:page_title] = CGI.escapeHTML(property['page_title'])
 				data[:modified_time] = property['source_time'].to_data_hash
 				append_referer(property)
-				property['count_int'] += 1
+				unless self.ignore_site_access?() then
+					property['count_int'] += 1
+				end
 			}
 			
 			data[:page_id_uri] = URI.escape(page_id)
@@ -665,6 +686,9 @@ protected
 		date_list.collect!{ |date_pair|
 			date_pair[1]
 		}
+		if self.request_max_number > 0 then
+			date_list = date_list[0...self.request_max_number];
+		end
 		data[:recent] ={ :date_list => date_list }
 		make_response_from_template('recent.html')
 	end
@@ -699,6 +723,9 @@ protected
 			page_data
 		}
 		page_list.delete(nil)
+		if self.request_max_number > 0 then
+			page_list = page_list[0...self.request_max_number];
+		end
 		data[:page_list] = page_list
 		data[:server_uri] = self.server_uri
 
@@ -719,6 +746,7 @@ protected
 		default_language = request_parameters['default_language'].to_s.untaint
 		default_language = 'en' if default_language.length <= 0
 		languages = request_parameters['languages'].to_s.untaint
+		ignore_sites = request_parameters['ignore_sites'].to_s.untaint
 
 		self.page_data_source.site_property(){ |property|
 			if admin_login_ok?(property, admin_passwd) then
@@ -730,6 +758,7 @@ protected
 				property['sidebar_control'] = sidebar_control 
 				property['default_language'] = default_language 
 				property['languages'] = languages 
+				property['ignore_sites'] = ignore_sites 
 				self.site_property = property
 				data[:site_property_change_ok] = true
 			else
@@ -822,6 +851,7 @@ protected
 		end
 
 		data[:languages] = self.site_property['languages']
+		data[:ignore_sites] = self.site_property['ignore_sites']
 		make_response_from_template('admin.html')
 	end
 
@@ -887,6 +917,17 @@ protected
 		@request_command 
 	end
 
+	def request_max_number()
+		unless @request_max_number then
+			@request_max_number = request_parameters['n'].to_s
+			@request_max_number = 0 if @request_max_number.length <= 0 
+			@request_max_number = @request_max_number.to_i
+			@request_max_number.untaint
+		end
+		@request_max_number
+	end
+
+
 	def request_page_id(default_page_id = nil)
 		unless @request_page_id then
 			@request_page_id = request_parameters['p'].to_s
@@ -896,6 +937,7 @@ protected
 		@request_page_id
 	end
 
+
 	def request_content_source()
 		unless @request_content_source then
 			@request_content_source = request_parameters['content_source'].to_s
@@ -957,6 +999,7 @@ protected
 		@request_language_list
 	end
 
+
 	def site_common_data()
 		result ={}
 		result[:script_path] = self.script_path
@@ -1206,7 +1249,7 @@ class Time
 		minutes = offset / 60 
 		hours = minutes / 60
 		minutes = minutes % 60
-		zone = sprintf("GMT%s%d:%02d", flag, hours, minutes)
+		zone = sprintf("%s%d:%02d", flag, hours, minutes)
 		{
 			:yyyy => self.strftime("%Y"),
 			:yy => self.strftime("%y"),
