@@ -40,28 +40,45 @@ module PropertyFile
 		property
 	end
 
+	def load(file_name, default_property = {})
+		property = default_property
+
+		if File.file?(file_name) and File.readable?(file_name) then
+			File.open(file_name, "r") { |prop_file|
+				prop_file.flock(File::LOCK_EX) 
+				property = read_property(prop_file, default_property)
+				prop_file.flock(File::LOCK_UN) 
+			}
+		end
+
+		property
+	end
+
+
 	def read_property(input, default_property = {})
 		property = default_property.dup
 		input.each(){ |line|
 			line.chomp!(EOL)
 			line.chomp!()
-			key, value = line.split('=', 2)
-			case key
-			when /_time$/ then
-				value = str2time(value)
-			when /_int$/ then
-				value = value.to_i
-			when /^is_/ then
-				case value.downcase
-				when 'true', 'yes' then
-					value = true
-				else
-					value = false
+			if (line =~ /=/) and (not line =~ /^#/) then
+				key, value = line.split('=', 2)
+				case key
+				when /_time$/ then
+					value = str2time(value)
+				when /_int$/ then
+					value = value.to_i
+				when /^is_/, /^use_/, /^enable_/ then
+					case value.downcase
+					when 'true', 'yes' then
+						value = true
+					else
+						value = false
+					end
+				when nil then
+					value = ''
 				end
-			when nil then
-				value = ''
+				property[key] = value
 			end
-			property[key] = value
 		}
 		return property;
 	end
@@ -73,7 +90,7 @@ module PropertyFile
 				value = time2str(value)
 			when /_int$/ then
 				value = value.to_s
-			when /^is_/ then
+			when /^is_/, /^use_/, /^enable_/ then
 				value = value ? 'true' : 'false'
 			else
 				value = '' unless value
@@ -98,6 +115,7 @@ module PropertyFile
 	end
 
 	module_function :property
+	module_function :load
 	module_function :read_property
 	module_function :write_property
 	module_function :str2time
